Task: One Common
======================
Description: A collaborative referring task which requires advanced skills of common grounding under continuous and partially-observable context. This code also includes reference-resolution annotation from Udagawa and Aizawa '19.

Link: https://arxiv.org/abs/1907.03399, https://arxiv.org/abs/1911.07588

Tags: #OneCommon, #All, #CommonGrounding
